@@ -68,6 +68,9 @@ INTERNALERROR_QUERYDATABASEFAILED = 'InternalError.QueryDatabaseFailed'
 # Internal system error.
 INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'
 
+# Unknown internal error.
+INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
+
 # Parameter error.
 INVALIDPARAMETER = 'InvalidParameter'
 
