@@ -292,9 +292,9 @@ class DescribeAbnormalEventRequest(AbstractModel):
         r"""
         :param SdkAppId: User `SDKAppID`, which can be used to query 20 exceptional experience events (in one or more rooms)
         :type SdkAppId: str
-        :param StartTime: Query start time
+        :param StartTime: Query start time (s) in the format of Unix timestamp, e.g., 1592448600
         :type StartTime: int
-        :param EndTime: Query end time
+        :param EndTime: Query end time (s) in the format of Unix timestamp, e.g., 1592449080
         :type EndTime: int
         :param RoomId: Room ID, which can be used to query up to 20 exceptional experience events in a specific room
         :type RoomId: str
@@ -358,11 +358,11 @@ class DescribeCallDetailRequest(AbstractModel):
         r"""
         :param CommId: Unique ID of a call: sdkappid_roomgString_createTime. The `roomgString` refers to the room ID, and `createTime` refers to the creation time of a room in the format of UNIX timestamp in seconds, such as 1400353843_218695_1590065777. Its value can be obtained from the `DescribeRoomInformation` API (related document: https://intl.cloud.tencent.com/document/product/647/44050?from_cn_redirect=1).
         :type CommId: str
-        :param StartTime: Query start time in the format of UNIX timestamp, such as 1588031999s, which is a point in time in the last 14 days.
+        :param StartTime: Query start time (s) in the format of Unix timestamp (e.g., 1590065777), which must be a time point in the last 14 days. The start and end time for query must not be more than 1 hour apart.
         :type StartTime: int
-        :param EndTime: Query end time in the format of local UNIX timestamp, such as 1588031999s.
+        :param EndTime: Query end time (s) in the format of Unix timestamp, e.g., 1590065877
         :type EndTime: int
-        :param SdkAppId: User `SDKAppID`, such as 1400188366.
+        :param SdkAppId: `SDKAppID` of the users to query, e.g., 1400353843
         :type SdkAppId: str
         :param UserIds: User array to query, which contains up to 6 users. If it is left empty, 6 users will be returned by default.
         :type UserIds: list of str
@@ -462,9 +462,9 @@ class DescribeDetailEventRequest(AbstractModel):
         r"""
         :param CommId: Unique ID of a call: sdkappid_roomgString_createTime. The `roomgString` refers to the room ID, and `createTime` refers to the creation time of a room in the format of UNIX timestamp in seconds. Its value can be obtained from the `DescribeRoomInformation` API (related document: https://intl.cloud.tencent.com/document/product/647/44050?from_cn_redirect=1).
         :type CommId: str
-        :param StartTime: Query start time in the format of UNIX timestamp, such as 1588031999s, which is a point in time in the last 14 days.
+        :param StartTime: Query start time (s) in the format of Unix timestamp (e.g., 1588055615), which must be a time point in the last 14 days
         :type StartTime: int
-        :param EndTime: Query end time in the format of local UNIX timestamp, such as 1588031999s.
+        :param EndTime: Query end time (s) in the format of Unix timestamp, e.g., 1588058615
         :type EndTime: int
         :param UserId: User ID
         :type UserId: str
@@ -500,7 +500,7 @@ class DescribeDetailEventResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Data: List of returned events
+        :param Data: List of returned events. An empty array will be returned if no data can be found.
         :type Data: list of EventList
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
         :type RequestId: str
@@ -526,11 +526,11 @@ class DescribeHistoryScaleRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param SdkAppId: User `sdkappid`
+        :param SdkAppId: `SDKAppID` of the users to query, e.g., 1400188366
         :type SdkAppId: str
-        :param StartTime: Query start time in the format of local UNIX timestamp, such as 1588031999s, which is a point in time in the last 5 days.
+        :param StartTime: Query start time (s) in the format of Unix timestamp (e.g., 1587571000), which must be a time point in the last 5 days
         :type StartTime: int
-        :param EndTime: Query end time in the format of local UNIX timestamp, such as 1588031999s.
+        :param EndTime: Query end time (s) in the format of Unix timestamp, e.g., 1588034999
         :type EndTime: int
         """
         self.SdkAppId = None
@@ -850,9 +850,9 @@ class DescribeRoomInformationRequest(AbstractModel):
         r"""
         :param SdkAppId: User `sdkappid`
         :type SdkAppId: str
-        :param StartTime: Query start time in the format of UNIX timestamp, such as 1588031999s, which is a point in time in the last 14 days.
+        :param StartTime: Query start time (s) in the format of Unix timestamp (e.g., 1588031999), which must be a time point in the last 14 days
         :type StartTime: int
-        :param EndTime: Query end time in the format of local UNIX timestamp, such as 1588031999s.
+        :param EndTime: Query end time (s) in the format of Unix timestamp, e.g., 1588034999
         :type EndTime: int
         :param RoomId: Room ID in string type
         :type RoomId: str
@@ -924,11 +924,11 @@ class DescribeUserInformationRequest(AbstractModel):
         r"""
         :param CommId: Unique ID of a call: sdkappid_roomgString_createTime. The `roomgString` refers to the room ID, and `createTime` refers to the creation time of a room in the format of UNIX timestamp in seconds, such as 1400353843_218695_1590065777. Its value can be obtained from the `DescribeRoomInformation` API (related document: https://intl.cloud.tencent.com/document/product/647/44050?from_cn_redirect=1).
         :type CommId: str
-        :param StartTime: Query start time in the format of UNIX timestamp (e.g. 1588031999s) in the last 5 days.
+        :param StartTime: Query start time (s) in the format of Unix timestamp (e.g., 1590065777), which must be a time point in the last 14 days
         :type StartTime: int
-        :param EndTime: Query end time in the format of UNIX timestamp (e.g. 1588031999s).
+        :param EndTime: Query end time (s) in the format of Unix timestamp (e.g., 1590065877)
         :type EndTime: int
-        :param SdkAppId: User `SDKAppID` (e.g. 1400188366).
+        :param SdkAppId: `SDKAppID` of the users to query, e.g., 1400353843
         :type SdkAppId: str
         :param UserIds: The array of user IDs for query. You can enter up to 6 user IDs. If it is left empty, data of 6 users will be returned.
         :type UserIds: list of str
@@ -1120,6 +1120,8 @@ Grey: 0x999999, whose decimal number is 10066329
         :type BackgroundImageId: int
         :param AudioCodec: Output audio codec for On-Cloud MixTranscoding. Valid values: 0, 1, 2. 0 (default): LC-AAC; 1: HE-AAC; 2: HE-AACv2. If this parameter is set to 2 (HE-AACv2), On-Cloud MixTranscoding can produce only dual-channel streams. If it is set to 1 (HE-AAC) or 2 (HE-AACv2), the valid values for the audio sample rate of output streams are 48000, 44100, 32000, 24000, and 16000.
         :type AudioCodec: int
+        :param BackgroundImageUrl: URL of the background image for the mixed stream, which can be in PNG, JPG, JPEG, or BMP format and does not support the alpha channel. The URL must not exceed 512 bytes. When both `BackgroundImageUrl` and `BackgroundImageId` are specified, the former will be used. The background image must not exceed 10 MB.
+        :type BackgroundImageUrl: str
         """
         self.AudioSampleRate = None
         self.AudioBitrate = None
@@ -1132,6 +1134,7 @@ Grey: 0x999999, whose decimal number is 10066329
         self.BackgroundColor = None
         self.BackgroundImageId = None
         self.AudioCodec = None
+        self.BackgroundImageUrl = None
 
 
     def _deserialize(self, params):
@@ -1146,6 +1149,7 @@ Grey: 0x999999, whose decimal number is 10066329
         self.BackgroundColor = params.get("BackgroundColor")
         self.BackgroundImageId = params.get("BackgroundImageId")
         self.AudioCodec = params.get("AudioCodec")
+        self.BackgroundImageUrl = params.get("BackgroundImageUrl")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2154,12 +2158,15 @@ class WaterMarkParams(AbstractModel):
         :type LocationX: int
         :param LocationY: Vertical offset (px) of the watermark
         :type LocationY: int
+        :param WaterMarkUrl: URL of the watermark image for the mixed stream, which can be in PNG, JPG, JPEG, or BMP format and does not support the alpha channel. The URL must not exceed 512 bytes. When both `WaterMarkUrl` and `WaterMarkId` are specified, the former will be used. The watermark image cannot exceed 10 MB.
+        :type WaterMarkUrl: str
         """
         self.WaterMarkId = None
         self.WaterMarkWidth = None
         self.WaterMarkHeight = None
         self.LocationX = None
         self.LocationY = None
+        self.WaterMarkUrl = None
 
 
     def _deserialize(self, params):
@@ -2168,6 +2175,7 @@ class WaterMarkParams(AbstractModel):
         self.WaterMarkHeight = params.get("WaterMarkHeight")
         self.LocationX = params.get("LocationX")
         self.LocationY = params.get("LocationY")
+        self.WaterMarkUrl = params.get("WaterMarkUrl")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
